summaryrefslogtreecommitdiff
path: root/src/unit.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/unit.h')
-rw-r--r--src/unit.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/unit.h b/src/unit.h
index 34e86d1086..f657aea3e2 100644
--- a/src/unit.h
+++ b/src/unit.h
@@ -108,7 +108,8 @@ enum UnitDependency {
UNIT_WANTED_BY, /* inverse of 'wants' */
/* Negative dependencies */
- UNIT_CONFLICTS, /* inverse of 'conflicts' is 'conflicts' */
+ UNIT_CONFLICTS, /* inverse of 'conflicts' is 'conflicted_by' */
+ UNIT_CONFLICTED_BY,
/* Order */
UNIT_BEFORE, /* inverse of 'before' is 'after' and vice versa */